# [Yummy](https://github.com/yummyml/yummy) - delicious MLOps tools.

Yummy project contains several tools and components which can help build and speedup the MLOps process.
Most of the code is written in rust 🦀 but components expose easy to use python api. 

| Package         | Description                                                                           | Documentation                       | Youtube
| --------------  | ------------------------------------------------------------------------------------- | ----------------------------------- | --------------
| yummy[feast]    | Yummy [feast](https://docs.feast.dev/) feature store extensions                       | [📄README](yummy)                   | 🎞[YT](https://www.youtube.com/watch?v=YinQxF4Gx54)
| yummy[features] | Yummy features server compatble with [Feast](https://docs.feast.dev/) feature store   | [📄README](yummy-rs/yummy-features-py) | 🎞[YT](https://www.youtube.com/watch?v=lXCJLc3hWgY)
| yummy[mlflow]   | Yummy [mlflow](https://www.mlflow.org/) models server                                 | [📄README](yummy-rs/yummy-mlflow-py)   | 🎞[YT](https://www.youtube.com/watch?v=rjNZ1RwBlCA)
| yummy[delta]    | Yummy [delta lake](https://delta.io/) api                                             | [📄README](yummy-rs/yummy-delta-py)    | 🎞Soon


